==> igniteui-webcomponents-core-3.5.0.tgz: package/esm5/lib/GridCellEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { CellInfoDescriptionMetadata } from "./CellInfoDescriptionMetadata";
import { DataGridDescriptionMetadata } from "./DataGridDescriptionMetadata";
import { GridCellEventArgsDescription } from "./GridCellEventArgsDescription";
/**
 * @hidden
 */
var GridCellEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(GridCellEventArgsDescriptionMetadata, _super);
    function GridCellEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    GridCellEventArgsDescriptionMetadata.b = function (a) {
        if (GridCellEventArgsDescriptionMetadata.a == null) {
            GridCellEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            GridCellEventArgsDescriptionMetadata.c(GridCellEventArgsDescriptionMetadata.a);
        }
        if (a.j(GridCellEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.y(GridCellEventArgsDescriptionMetadata.a);
        CellInfoDescriptionMetadata.d(a);
        DataGridDescriptionMetadata.d(a);
    };
    GridCellEventArgsDescriptionMetadata.c = function (a) {
        a.item("CellInfo", "ExportedType:CellModel");
        a.item("Grid", "ExportedType:Grid");
        a.item("Button", "ExportedType:string:MouseButton");
        a.item("Button@names", "Left;Middle;Right;Unkown");
        a.item("IsDoubleClick", "Boolean");
    };
    GridCellEventArgsDescriptionMetadata.d = function (a) {
        GridCellEventArgsDescriptionMetadata.b(a);
        a.aa("GridCellEventArgs", function () { return new GridCellEventArgsDescription(); });
        a.z("GridCellEventArgs", GridCellEventArgsDescriptionMetadata.a);
    };
    GridCellEventArgsDescriptionMetadata.$t = markType(GridCellEventArgsDescriptionMetadata, 'GridCellEventArgsDescriptionMetadata');
    GridCellEventArgsDescriptionMetadata.a = null;
    return GridCellEventArgsDescriptionMetadata;
}(Base));
export { GridCellEventArgsDescriptionMetadata };

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/GridCellEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { CellInfoDescriptionMetadata } from "./CellInfoDescriptionMetadata";
import { DataGridDescriptionMetadata } from "./DataGridDescriptionMetadata";
import { GridCellEventArgsDescription } from "./GridCellEventArgsDescription";
/**
 * @hidden
 */
var GridCellEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(GridCellEventArgsDescriptionMetadata, _super);
    function GridCellEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    GridCellEventArgsDescriptionMetadata.b = function (a) {
        if (GridCellEventArgsDescriptionMetadata.a == null) {
            GridCellEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            GridCellEventArgsDescriptionMetadata.c(GridCellEventArgsDescriptionMetadata.a);
        }
        if (a.k(GridCellEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.aa(GridCellEventArgsDescriptionMetadata.a);
        CellInfoDescriptionMetadata.d(a);
        DataGridDescriptionMetadata.d(a);
    };
    GridCellEventArgsDescriptionMetadata.c = function (a) {
        a.item("CellInfo", "ExportedType:CellModel");
        a.item("Grid", "ExportedType:Grid");
        a.item("Button", "ExportedType:string:MouseButton");
        a.item("Button@names", "Left;Middle;Right;Unkown");
        a.item("IsDoubleClick", "Boolean");
    };
    GridCellEventArgsDescriptionMetadata.d = function (a) {
        GridCellEventArgsDescriptionMetadata.b(a);
        a.ac("GridCellEventArgs", function () { return new GridCellEventArgsDescription(); });
        a.ab("GridCellEventArgs", GridCellEventArgsDescriptionMetadata.a);
    };
    GridCellEventArgsDescriptionMetadata.$t = markType(GridCellEventArgsDescriptionMetadata, 'GridCellEventArgsDescriptionMetadata');
    GridCellEventArgsDescriptionMetadata.a = null;
    return GridCellEventArgsDescriptionMetadata;
}(Base));
export { GridCellEventArgsDescriptionMetadata };
